@@ -1,11 +1,14 @@
 #![warn(missing_debug_implementations, rust_2018_idioms, unreachable_pub)]
-#![deny(warnings)]
 #![forbid(unsafe_code)]
-// can we have a lint for spaces in doc comments please?
+// deny warnings in CI
+#![cfg_attr(gotham_restful_deny_warnings, allow(renamed_and_removed_lints))]
+#![cfg_attr(gotham_restful_deny_warnings, deny(warnings))]
+// clippy doesn't like our code style
 #![cfg_attr(feature = "cargo-clippy", allow(clippy::tabs_in_doc_comments))]
 // intra-doc links only fully work when OpenAPI is enabled
 #![cfg_attr(feature = "openapi", deny(broken_intra_doc_links))]
 #![cfg_attr(not(feature = "openapi"), allow(broken_intra_doc_links))]
+
 /*!
 This crate is an extension to the popular [gotham web framework][gotham] for Rust. It allows you to
 create resources with assigned endpoints that aim to be a more convenient way of creating handlers
@@ -84,9 +87,8 @@ Defining custom endpoints is done with the `#[endpoint]` macro. The syntax is si
 of the pre-defined endpoints, but you need to give it more context:
 
 ```rust,no_run
-# #[macro_use] extern crate gotham_derive;
 # #[macro_use] extern crate gotham_restful_derive;
-# use gotham::router::builder::*;
+# use gotham::{router::build_simple_router, prelude::*};
 # use gotham_restful::*;
 # use serde::{Deserialize, Serialize};
 use gotham_restful::gotham::hyper::Method;
@@ -218,7 +220,7 @@ A simple example that uses only a single secret looks like this:
 # #[macro_use] extern crate gotham_restful_derive;
 # #[cfg(feature = "auth")]
 # mod auth_feature_enabled {
-# use gotham::{router::builder::*, pipeline::{new_pipeline, single::single_pipeline}, state::State};
+# use gotham::{router::builder::*, pipeline::*, state::State};
 # use gotham_restful::*;
 # use serde::{Deserialize, Serialize};
 #[derive(Resource)]
@@ -271,7 +273,7 @@ authentication), and every content type, looks like this:
 # #[macro_use] extern crate gotham_restful_derive;
 # #[cfg(feature = "cors")]
 # mod cors_feature_enabled {
-# use gotham::{hyper::header::*, router::builder::*, pipeline::{new_pipeline, single::single_pipeline}, state::State};
+# use gotham::{hyper::header::*, router::builder::*, pipeline::*, state::State};
 # use gotham_restful::{*, cors::*};
 # use serde::{Deserialize, Serialize};
 #[derive(Resource)]
@@ -316,7 +318,7 @@ A simple non-async example looks like this:
 # #[cfg(feature = "database")]
 # mod database_feature_enabled {
 # use diesel::{table, PgConnection, QueryResult, RunQueryDsl};
-# use gotham::{router::builder::*, pipeline::{new_pipeline, single::single_pipeline}, state::State};
+# use gotham::{router::builder::*, pipeline::*, state::State};
 # use gotham_middleware_diesel::DieselMiddleware;
 # use gotham_restful::*;
 # use serde::{Deserialize, Serialize};
@@ -441,8 +443,6 @@ compile_error!("Either the 'openapi' or 'without-openapi' feature needs to be en
 // weird proc macro issue
 extern crate self as gotham_restful;
 
-#[macro_use]
-extern crate gotham_derive;
 #[macro_use]
 extern crate gotham_restful_derive;
 #[macro_use]
